# coding: utf-8

import ctypes


class Ctx64(ctypes.Structure):
    """
    Defines the ICEDID core's context structure for 64-bit systems.

    Attributes:
        field_0 (int): An 8-bit field, purpose unspecified
        is_dll (int): An 8-bit flag indicating if the context is for a DLL
        stage_2_fullpath (bytes): Full path to stage 2 (260 bytes)
        core_fullpath (bytes): Full path to the core (260 bytes)
        core_subpath (bytes): Subpath within the core (260 bytes)
        stage_2_export (bytes): Export name for stage 2 (64 bytes)
        encrypted_config (ctypes.c_void_p): Pointer to the encrypted configuration
        encrypted_config_size (int): Size of the encrypted configuration (64-bit)
        field_35e (bytes): Unknown field (4 bytes)
    """

    _pack_ = 1
    _fields_ = [
        ("field_0", ctypes.c_ubyte),
        ("is_dll", ctypes.c_ubyte),
        ("stage_2_fullpath", ctypes.c_char * 260),
        ("core_fullpath", ctypes.c_char * 260),
        ("core_subpath", ctypes.c_char * 260),
        ("stage_2_export", ctypes.c_char * 64),
        ("encrypted_config", ctypes.c_void_p),
        ("encrypted_config_size", ctypes.c_uint64),
        ("field_35e", ctypes.c_byte * 4),
    ]


EntryPointFunction = ctypes.WINFUNCTYPE(ctypes.c_uint64, ctypes.POINTER(Ctx64))
