# coding: utf-8

from nightMARE.analysis import reversing


def decrypt_string(encrypted_bytes: bytes) -> bytes:
    """
    This function decrypts encrypted strings using the LATRODECTUS algorithm.

    :param encrypted_bytes: The encrypted string data as a byte sequence to decrypt.
    :return: The decrypted string as a byte sequence.
    """

    r2 = reversing.Radare2.get(encrypted_bytes)
    x = r2.get_u32(0)
    y = r2.get_u16(4)

    byte_size = (x ^ y) & 0xFFFF
    decoded_bytes = bytearray(byte_size)

    for i, b in enumerate(r2.get_data(6, byte_size)):
        decoded_bytes[i] = ((x + i + 1) ^ b) % 256

    return bytes(decoded_bytes)
